//
//  Batch.h
//  Batch
//
//  http://batch.com
//  Copyright (c) 2014 Batch SDK. All rights reserved.
//

#import <Foundation/Foundation.h>

/*!
 @class Batch
 @abstract Call for all you need for Batch usage in your application.
 @discussion Actions you can perform in Batch.
 @version v1.0 RC 1 - API level 2
 @updated on 2014-07-04
 @availability from iOS 5.0
 */
@interface Batch : NSObject

/*!
 @method startWithAPIKey:
 @abstract Activate the whole Batch system.
 @discussion Call this method in application:didFinishLaunchingWithOptions: of your UIApplicationDelegate
 @discussion You can call this method from any thread, the start process is execute in background.
 @param key    :   Your API private key.
 */
+ (void)startWithAPIKey:(NSString *)key NS_AVAILABLE_IOS(5_0);

/*!
 @method handleURL:
 @abstract Give the URL to Batch systems.
 @discussion Call this method in application:openURL:sourceApplication:annotation: of your UIApplicationDelegate
 @discussion You can call this method from any thread.
 @param url         :   The input URL. Batch handle only it's own URL scheme and ignore others.
 @warning The delegate methods is always called in the main thread!
 */
+ (void)handleURL:(NSURL *)url NS_AVAILABLE_IOS(5_0);

/*!
 @method isRunningInDevelopmentMode
 @abstract Test if Batch is running in development mode.
 @discussion You can call this method from any thread.
 @return YES if Batch is Running AND if it uses a development API key.
 */
+ (BOOL)isRunningInDevelopmentMode NS_AVAILABLE_IOS(5_0);

/*!
 @method setCustomUserIdentifier:
 @abstract Set the custom user identifier to Batch, you should use this method if you have your own login system.
 @discussion You can call this method from any thread.
 @param identifier  :   The unique user identifier.
 @warning  Be carefull: Do not use it if you don't know what you are doing, giving a bad custom user ID can result in failure into offer delivery and restore.
 */
+ (void)setCustomUserIdentifier:(NSString *)identifier NS_AVAILABLE_IOS(5_0);

/*!
 @method setUseIDFA:
 @abstract Set if Batch can try to use IDFA (default = YES)
 @discussion Setting this to NO have a negative impact on offer delivery and restore.
 @param use :   YES if Batch can try to use the IDFA, NO if you don't want Batch to use the IDFA.
 @warning You should only use it if you know what you are doing.
 */
+ (void)setUseIDFA:(BOOL)use NS_AVAILABLE_IOS(5_0);

@end